<!DOCTYPE html><html class="no-js" xmlns:ng="http://angularjs.org" xmlns:app="ignored" ng-app="app"><head><meta charset="utf-8"><meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1"></head><title window-title>Buildbot</title><meta name="description" content="Buildbot web UI"><meta name="viewport" content="initial-scale=1, minimum-scale=1, user-scalable=no, maximum-scale=1, width=device-width"><link rel="stylesheet" href="styles.css"><link rel="icon" href="img/favicon.ico"><body ng-cloak><gl-page-with-sidebar><gl-topbar><gl-topbar-contextual-actions></gl-topbar-contextual-actions><loginbar></loginbar></gl-topbar><connectionstatus></connectionstatus><ui-view></ui-view></gl-page-with-sidebar></body><script src="scripts.js?_1510091349984"></script>{% for app in config.plugins -%}<script src="{{app}}/scripts.js"></script><link rel="stylesheet" href="{{app}}/styles.css"><script>angular.module('app').requires.push('{{app}}')</script>{% endfor %}<script>angular.module("buildbot_config", []).constant("config", {{configjson|safe}})</script>{% if custom_templates %}<script>angular.module("app").run(function ($templateCache) {
{% for name, html in custom_templates.items() %}
 $templateCache.put("{{ name }}", {{ html|safe }});
{% endfor %}
})</script>{% endif %}</html>